@@ -4,7 +4,7 @@ import sys
 import warnings
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Any, Optional, Tuple
+from typing import Any, Dict, Optional, Tuple, Union
 
 import deprecation
 import matplotlib.pyplot as plt
@@ -18,7 +18,7 @@ NAME: str = "latexplotlib"
 CONFIGFILE: str = "config.ini"
 CONFIGDIR: Path = Path(user_config_dir(NAME))
 CONFIGPATH: Path = CONFIGDIR.joinpath(CONFIGFILE)
-DEFAULT_CONFIG: dict[str, int] = {"width": 630, "height": 412}
+DEFAULT_CONFIG: Dict[str, int] = {"width": 630, "height": 412}
 
 
 def export(sth: Any, name: Optional[str] = None):  # type: ignore
@@ -107,18 +107,24 @@ def reset_page_size():
 
 
 class Config:
+    @classmethod
+    def _ensure_path_exists(cls, path: Path):
+        if not path.parent.exists():
+            path.parent.mkdir()
+
     def __init__(self, path: Path):
+        self._ensure_path_exists(path)
         self.path = path
 
-    def _config(self) -> dict[str, Any]:
+    def _config(self) -> Dict[str, Any]:
         if not os.path.exists(self.path):
             self.reset()
 
         with open(self.path, "r", encoding="utf-8") as fh:
-            cfg: dict[str, Any] = json.load(fh)
+            cfg: Dict[str, Any] = json.load(fh)
             return cfg
 
-    def _write(self, cfg: dict[str, Any]):
+    def _write(self, cfg: Dict[str, Any]):
         with open(self.path, "w", encoding="utf-8") as fh:
             json.dump(cfg, fh, indent=4)
 
@@ -148,7 +154,7 @@ class Size:
     def __init__(self):
         self._width, self._height = config["width"], config["height"]
 
-    def get(self) -> tuple[int, int]:
+    def get(self) -> Tuple[int, int]:
         """Returns the current size of the figure in pts.
 
         Returns
@@ -225,22 +231,48 @@ def convert_pt_to_in(pts: int) -> float:
     return 12.0 * 249.0 / 250.0 / 864.0 * pts
 
 
-def _set_size(nrows, ncols, fraction: float = 1.0, ratio: float = GOLDEN_RATIO):
+@export
+def convert_in_to_to(inches: float) -> float:
+    """Converts a length in inch to a length in pt.
+
+    Parameters
+    ----------
+    inches : float
+        A length in inches.
+
+    Returns
+    -------
+    float
+        A length in pts.
+
+    References
+    ----------
+    - https://www.overleaf.com/learn/latex/Lengths_in_LaTeX
+    """
+    return inches * 864.0 * 250.0 / 249.0 / 12.0
+
+
+def _set_size(
+    nrows, ncols, fraction: float = 1.0, ratio: Union[float, str] = GOLDEN_RATIO
+):
+    EXCEPTION_STR = "fraction must be positive or 'any' or 'max'."
+    if fraction < 0 or (isinstance(ratio, str) and ratio not in ["any", "max"]):
+        raise ValueError(EXCEPTION_STR)
+
     max_width_pt, max_height_pt = size.get()
 
-    if fraction < 0:
-        raise ValueError("fraction must be positive!")
+    fraction = max(fraction, 1)
 
-    if fraction > 1:
-        width_pt: float = float(max_width_pt)
+    if isinstance(ratio, str):
+        width_pt, height_pt = fraction * max_width_pt, fraction * max_height_pt
     else:
-        width_pt = float(max_width_pt) * fraction
+        width_pt = max_width_pt * fraction
 
-    height_pt = width_pt / ratio * (nrows / ncols)
+        height_pt = width_pt / ratio * (nrows / ncols)
 
-    if height_pt > max_height_pt:
-        width_pt = width_pt * max_height_pt / height_pt
-        height_pt = max_height_pt
+        if height_pt > max_height_pt:
+            width_pt = width_pt * max_height_pt / height_pt
+            height_pt = max_height_pt
 
     return _round(convert_pt_to_in(width_pt)), _round(convert_pt_to_in(height_pt))
 
@@ -252,7 +284,7 @@ def figsize(fraction: float = 1.0, ratio: float = GOLDEN_RATIO):
 
 @export
 def subplots(
-    *args, fraction: float = 1.0, ratio=GOLDEN_RATIO, **kwargs
+    *args, fraction: float = 1.0, ratio: Union[float, str] = GOLDEN_RATIO, **kwargs
 ) -> Tuple[Any, Any]:
     """A wrapper for matplotlib's 'plt.subplots' method
 
